pub fn git_clone(url: &str) -> Result<GitRepo, Box<EvalAltResult>>Expand description
Clone a git repository to a temporary location
This function clones a repository from the given URL to a temporary directory and returns the GitRepo object for further operations.
Arguments
url- The URL of the git repository to clone
Returns
Ok(GitRepo)- The cloned repository objectErr(Box<EvalAltResult>)- If the clone operation failed